.TH XWPANEL 3X
.SH NAME
XwPanelWidgetClass \- An X Widget for creating panels.
.SH SYNOPSIS
#include <X11/StringDefs.h>
.br
#include <X11/Intrinsic.h>
.br
#include <Xw/Xw.h>
.br
#include <Xw/Panel.h>
.SH CLASSES
A subclass of Core, Composite, Constraint and
XwManagerClass.
.PP
The widget class to use when creating a Panel widget is
XwpanelWidgetClass.
.PP
The class name of Panel is Panel.
.SH DESCRIPTION
Panel provides a simple creation mechanism for the creation
of application windows and associated menus.  The panel
widget is also appropriate for application sub-windows.
.PP
Panel will manage three types of children. Panel may have at
most one child of each type.  The types are titlebar, menu,
and work space.  Children are associated with these types
via constraint resources (see below).  Panel ignores all
extra or unknown children.
.PP
Panel lays out its children such that the child of type
titlebar is on the top, the child of type menu is below, and
the child of type work space is on the bottom.  Display of
the titlebar child can be optionally inhibitted if the panel
is under the control of a window manager which provides
titlebars.
.PP
When Panel has its width changed by its parent, the menu, if
displayed, is allowed to pick its own height, the title
remains the same height and the work space is diminished or
enlarged to fill the remaining available space.  When Panel
has its height reduced by its parent, space is taken from
the work space until the work space is completely hidden.
Further reductions in the height of Panel are shared between
the title and the menu.  When Panel has its height increased
by its parent, if either the title or the menu are less than
their optimum height, they are given the space until they
reach their optimum height for the given width.  If both the
title and the menu are at their optimum height all space is
given to the work space.
.PP
The initial width of Panel is the widest of all its children
(padding is taken into account).  The initial height of
Panel is the sum of the heights of all its children and
their padding.
.PP
When an application is running in a Panel with a titling
window manager, there is a possibility of double titling.
Unfortunately, the application writer cannot know at the
time of development whether or not the user will have a
titling window manager. Panel has two resources which
together allow runtime decisions about titling.  The first,
XtNtopLevel, indicates whether the Panel is a canidate for
double titling.  The application must always set this
variable appropriately.  The second resource,
XtNdisplayTitle, indicates whether or not the Panel should
display a title.
.SH "NEW RESOURCES"
To specify any of these resources within a resource defaults
file, simply drop the XtN prefix from the resource name.
Panel defines the following new resources:
.IP "" 21
Panel Resource Set
.ti -26
Name                       Class                      Type      Default
.br
.ti -26
_______________________________________________________________________
.br
.ti -26
XtNtopLevel                XtCTopLevel                Boolean   TRUE
.br
.ti -26
XtNdisplayTitle            XtCDisplayTitle            Boolean   TRUE
.br
.ti -26
XtNvSpace XtCVSpace int 0
.br
.ti -26
XtNhSpace XtCHSpace int 0
.br
.ti -26
XtNtitleToMenuPad XtCTitleToMenuPad int 0
.br
.ti -26
XtNworkSpaceToSiblingPad   XtCWorkSpaceToSiblingPad   int       0
.br
.TP 5
XtNtopLevel
.br
Indicates whether not the panel is a candidate for
management by a window manager.  This should always be
set by the application.
.TP 5
XtNdisplayTitle
.br
Ignored if XtNtopLevel is FALSE.
.IP "" 5
Otherwise, if XtNdisplayTitle is TRUE, the titlebar
child will be displayed.  If XtNdisplayTitle is FALSE,
the titlebar child will not be displayed.
.IP "" 5
This resource should be set by the user in the resource
defaults file.  If the user runs the application
without a window manager or with a non-titling window
manager, this resource should be set to TRUE.  If the
user runs with a titling window manager this resource
should be set to FALSE.
.TP 5
XtNvSpace
.br
Padding between the top of the Panel and the top child
in pixels, and between the bottom of the Panel and the
bottom child in pixels.
.TP 5
XtNhSpace
.br
Padding between the sides of the Panel and the sides of
the displayed children.
.TP 5
XtNtitleToMenuPad
.br
If both a title and a menu child are being displayed,
the padding between them in pixels.
.PP
XtNworkSpaceToSiblingPad
.IP "" 5
The padding between the work space child and the
sibling above it.  If there is no title nor menu being
displayed this resource is ignored.
.SH "CONSTRAINT RESOURCES"
The following resources will be attached to every widget
inserted into Panel.  Refer to CONSTRAINT(3X) for a general
discussion of constraint resources.
.IP "" 3
Constraint Resource Set \-\- Children of PANEL(3X)
.ti -7
Name              Class             Type           Default
.br
.ti -7
_______________________________________________________________
.br
.ti -7
XtNwidgetType     XtCWidgetType     XwWidgetType   XwWORK_SPACE
.br
.ti -7
XtNcausesResize   XtCCausesResize   Boolean        FALSE
.br
.TP 5
XtNwidgetType
.br
Indicates to Panel what type of child it is.  The
possible values are, XwWORK_SPACE, specified in a
resource defaults file as "work space", XwTITLE,
specified in a resource defaults file as "title", and
XwPULLDOWN, specified in a resource defaults file as
"pulldown".
.TP 5
XtNcausesResize
.br
Controls whether changes in the child geometry can
cause the Panel to make a geometry request of its
parent.  If TRUE for only one child, Panel will request
changes whenever that child requests changes.  If TRUE
for multiple children, Panel will request changes
whenever any of that set of children grow, and when all
of that set of children have shrunk.
.PP
The behavior of this resource can be nullified by setting
XwNLayout to XwIGNORE.
.SH "INHERITED RESOURCES"
The following resources are inherited from the named
superclasses:
.IP "" 17
Core Resource Set \-\- CORE(3X)
.ti -22
Name                   Class                  Type             Default
.br
.ti -22
__________________________________________________________________________
.br
.ti -22
XtNancestorSensitive   XtCSenstitive          Boolean          TRUE
.br
.ti -22
XtNx                   XtCPosition            int              0
.br
.ti -22
XtNy                   XtCPosition            int              0
.br
.ti -22
XtNwidth               XtCWidth               int              0
.br
.ti -22
XtNheight              XtCHeight              int              0
.br
.ti -22
XtNdepth               XtCDepth               int              0
.br
.ti -22
XtNbackground          XtCBackground          Pixel            White
.br
.ti -22
XtNbackgroundPixmap    XtCPixmap              Pixmap           Unspecified
.br
.ti -22
XtNborderWidth         XtCBorderWidth         int              1
.br
.ti -22
XtNborderColor         XtCBorderColor         Pixel            Black
.br
.ti -22
XtNborderPixmap        XtCPixmap              Pixmap           Unspecified
.br
.ti -22
XtNsensitive           XtCSensitive           Boolean          TRUE
.br
.ti -22
XtNmappedWhenManaged   XtCMappedWhenManaged   Boolean          TRUE
.br
.ti -22
XtNdestroyCallback     XtCCallback            Pointer          NULL
.br
.ti -22
XtNtranslations        XtCTranslations        XtTranslations   NULL
.br
.IP "" 17
Manager Resource Set
.ti -20
Name                Class               Type      Default
.br
.ti -20
____________________________________________________________
.br
.ti -20
XtNforeground       XtCForeground       Pixel     Black
.br
.ti -20
XtNbackgroundTile   XtCBackgroundTile   int       background
.br
.ti -20
XtNtraversalOn      XtCTraversalOn      Boolean   FALSE
.br
.ti -20
XtNlayout           XtClayout           int       minimize
.br
.SH TRANSLATIONS
The default translation set defining is as follows:
.IP "" 5
<EnterWindow>:          enter()
.br
<LeaveWindow>:          leave()
.SH ACTIONS
enter:  If keyboard traversal is active (argument type
XtNtraversalOn with argument value TRUE), initiate keyboard
traversal.
.PP
leave:  If keyboard traversal is active (argument type
XtNtraversalOn with argument value TRUE), terminate keyboard
traversal.
.SH ORIGIN
Hewlett-Packard Company.
.SH "SEE ALSO"
CORE(3X), CONSTRAINT(3X), XWMANAGER(3X),
.br
Programming With The HP X Widgets,
.br
Programming With Xt Intrinsics,
.br
Programming With Xlib.
